#!/usr/local/sbin/charm-env python3
#
# Copyright 2016,2019 Canonical Ltd
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import os
import subprocess
import sys

from charmhelpers.core.hookenv import action_set, action_fail, log


def clear_sel():
    """Action to clear the IPMI system event log.

    Uses ipmi-sel --post-clear, clears the SEL log and stores the cleared entries
    in action output.
    """
    command = ['/usr/sbin/ipmi-sel', '--post-clear']
    try:
        output = subprocess.check_output(command)
        log("Action clear-sel completed, sel log cleared: {}".format(output))
        action_set({'message': output.decode('UTF-8')})
    except subprocess.CalledProcessError as e:
        action_fail("Action failed with {}".format(e))


# A dictionary of all the defined actions to callables (which take
# parsed arguments).
ACTIONS = {"clear-sel": clear_sel}


def main(args):
    action_name = os.path.basename(args[0])
    try:
        ACTIONS[action_name]()
    except Exception as e:
        action_fail(str(e))


if __name__ == "__main__":
    sys.exit(main(sys.argv))
